SWDEV-384100 - skip building failing texture tests for CUDA 12.0 (#181)
Change-Id: Ie861d63b0525661ff64ad148e5a0151bbce7db2c
[ROCm/hip-tests commit: df20298706]
This commit is contained in:
کامیت شده توسط
GitHub
والد
f9269a3dc2
کامیت
80c62e3b2e
@@ -20,6 +20,9 @@ THE SOFTWARE.
|
||||
#include <hip_test_common.hh>
|
||||
#include <hip_test_checkers.hh>
|
||||
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
#define SIZE_H 8
|
||||
#define SIZE_W 12
|
||||
#define TYPE_t float
|
||||
@@ -77,3 +80,6 @@ TEST_CASE("Unit_hipBindTexture2D_Pitch") {
|
||||
HIP_CHECK(hipFree(devPtrA));
|
||||
HIP_CHECK(hipFree(devPtrB));
|
||||
}
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
|
||||
@@ -19,6 +19,8 @@ THE SOFTWARE.
|
||||
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
#define N 512
|
||||
|
||||
texture<float, 1, hipReadModeElementType> tex;
|
||||
@@ -79,3 +81,7 @@ TEST_CASE("Unit_hipBindTexture_tex1DfetchVerification") {
|
||||
HIP_CHECK(hipFree(texBuf));
|
||||
HIP_CHECK(hipFree(devBuf));
|
||||
}
|
||||
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
|
||||
@@ -19,6 +19,9 @@ THE SOFTWARE.
|
||||
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
#define SIZE 10
|
||||
#define EPSILON 0.00001
|
||||
#define THRESH_HOLD 0.01 // For filter mode
|
||||
@@ -159,3 +162,5 @@ TEST_CASE("Unit_hipNormalizedFloatValueTex_CheckModes") {
|
||||
runTest_hipTextureFilterMode<hipFilterModeLinear>();
|
||||
}
|
||||
}
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
@@ -20,6 +20,8 @@ THE SOFTWARE.
|
||||
#include <hip_test_common.hh>
|
||||
#include <hip_test_checkers.hh>
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
typedef float T;
|
||||
|
||||
// Texture reference for 2D Layered texture
|
||||
@@ -107,3 +109,6 @@ TEST_CASE("Unit_hipSimpleTexture2DLayered_Check") {
|
||||
free(hData);
|
||||
free(hOutputData);
|
||||
}
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
|
||||
@@ -20,6 +20,8 @@ THE SOFTWARE.
|
||||
#include <hip_test_common.hh>
|
||||
#include <hip_test_checkers.hh>
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
// Texture reference for 3D texture
|
||||
texture<float, hipTextureType3D, hipReadModeElementType> texf;
|
||||
texture<int, hipTextureType3D, hipReadModeElementType> texi;
|
||||
@@ -119,3 +121,7 @@ TEST_CASE("Unit_hipSimpleTexture3D_Check_DataTypes") {
|
||||
runSimpleTexture3D_Check<char>(i, i+1, i, &texc);
|
||||
}
|
||||
}
|
||||
|
||||
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
@@ -19,6 +19,9 @@ THE SOFTWARE.
|
||||
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
|
||||
#if CUDA_VERSION < CUDA_12000
|
||||
|
||||
texture<float, 2, hipReadModeElementType> tex;
|
||||
|
||||
__global__ void tex2DKernel(float* outputData, int width) {
|
||||
@@ -90,3 +93,7 @@ TEST_CASE("Unit_hipTextureRef2D_Check") {
|
||||
HIP_CHECK(hipFree(dData));
|
||||
HIP_CHECK(hipFreeArray(hipArray));
|
||||
}
|
||||
|
||||
|
||||
#endif // CUDA_VERSION < CUDA_12000
|
||||
|
||||
|
||||
مرجع در شماره جدید
Block a user